@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 from .transformer import Transformer
-from sklearn.externals.joblib import Parallel, delayed
+from joblib import Parallel, delayed
 from ..techniques.technique import PositionVariantTechnique
 
 
@@ -21,4 +21,4 @@ class TransformerForImageStackSegmentation(Transformer):
             delayed(self.technique.apply)(image) for image in listMasks if image is not None)
             return [newlistImages,newListMasks]
         else:
-            return [newlistImages, listMasks]
\ No newline at end of file
+            return [newlistImages, listMasks]
